# 🐄 MuCOS

> pronounced: "moo-cos"

Multi-SuCOS: Score derivative compounds based how well they recapitulate the shape and colour of multiple (fragment) inspiration hits 

## Based on:

- [SuCOS](https://github.com/susanhleung/SuCOS)
- [OpenEye Tversky](https://docs.eyesopen.com/applications/rocs/theory/measure_similarity.html#tversky)
- [Malhotra and Karanicolas' COS measure](https://pubs.acs.org/doi/abs/10.1021/acs.jmedchem.6b00725)
